==> order-center-api-3.2.2-CLOUD-DEV-20240507.074420-10-sources.jar: com/tydic/dyc/oc/service/saleorder/bo/UocGetSaleOrderDetailServiceRspInspOrderInfoBo.java <==
package com.tydic.dyc.oc.service.saleorder.bo;

import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocGetSaleOrderDetailServiceRspInspOrderInfoBo
 * 说明:验收单信息
 * 时间:2022-02-21 19:11
 * 作者:tkl
 **/
@Data
@EqualsAndHashCode(callSuper=false)
public class UocGetSaleOrderDetailServiceRspInspOrderInfoBo implements Serializable {
    private static final long serialVersionUID = -6687385746152916212L;

    /**验收单id*/
    private Long inspOrderId;

    /**执行明细id*/
    private Long implOrderItemId;

    /**销售单id*/
    private Long saleOrderId;

    /**订单id*/
    private Long orderId;

    /**发货单编码*/
    private String inspOrderNo;

    /**外部发货单编码*/
    private String inspOrderNoExt;

    /**验收单名称*/
    private String inspOrderName;

    /**验收单类型*/
    private Integer inspOrderType;

    /**验收单状态*/
    private String inspOrderState;

    /**验收单状态翻译*/
    private String inspOrderStateStr;

    /**销售金额*/
    private BigDecimal totalSaleFee;

    /**采购金额*/
    private BigDecimal totalPurchaseFee;

    /**实付金额*/
    private BigDecimal usedFee;

    /**开票标识 0未开票 1已开票*/
    private Integer invoiceTag;

    /**流转状态*/
    private String procState;

    /**对账状态*/
    private String checkState;

    /**租户ID*/
    private String tenantId;

    /**竣工标志             1 竣工             0 在途*/
    private Integer finishFlag;

    /**创建时间*/
    private Date createTime;

    /**创建工号*/
    private String createOperId;

    /**验收人电话*/
    private String inspOperPhone;

    /**验收人名字*/
    private String inspOper;

    /**更新时间*/
    private Date updateTime;

    /**更新工号*/
    private String updateOperId;

    /**撤单时间*/
    private Date cancelTime;

    /**撤单工号*/
    private String cancelOperId;

    /**撤单原因*/
    private String cancelReason;

    /**撤单标志:1 已撤单             0 未撤单*/
    private Integer cancelFlag;

    /**备注*/
    private String remark;

    /**其它备注*/
    private String otherRemark;

    /**竣工时间*/
    private Date finishTime;

    /**逾期时间*/
    private Date expTime;

    /**总金额*/
    private BigDecimal totalFee;

    /**总数量*/
    private Integer totalCount;

    /**验收明细*/
    private List<UocGetSaleOrderDetailServiceRspInspOrderItemInfoBo> inspOrderItemInfo;

    /**验收发货关系*/
    private List<UocGetSaleOrderDetailServiceRspShipInspRelBo> shipInspRel;

    /**纵向扩展*/
    private List<UocGetSaleOrderDetailServiceRspInspOrderExtParallelBo> extParallelBoList;

}

==> order-center-api-3.3.0-CLOUD-DEV-20251124.032440-3-sources.jar: com/tydic/dyc/oc/service/saleorder/bo/UocGetSaleOrderDetailServiceRspInspOrderInfoBo.java <==
package com.tydic.dyc.oc.service.saleorder.bo;

import com.tydic.dyc.base.core.dictionary.annotation.DictField;
import com.tydic.dyc.oc.constants.UocStateConstants;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocGetSaleOrderDetailServiceRspInspOrderInfoBo
 * 说明:验收单信息
 * 时间:2022-02-21 19:11
 * 作者:tkl
 **/
@Data
@EqualsAndHashCode(callSuper=false)
public class UocGetSaleOrderDetailServiceRspInspOrderInfoBo implements Serializable {
    private static final long serialVersionUID = -6687385746152916212L;

    /**验收单id*/
    private Long inspOrderId;

    /**执行明细id*/
    private Long implOrderItemId;

    /**销售单id*/
    private Long saleOrderId;

    /**订单id*/
    private Long orderId;

    /**发货单编码*/
    private String inspOrderNo;

    /**外部发货单编码*/
    private String inspOrderNoExt;

    /**验收单名称*/
    private String inspOrderName;

    /**验收单类型*/
    private Integer inspOrderType;

    /**验收单状态*/
    @DictField(busiCenter = "UOC_PRO",pCode = UocStateConstants.InspOrder.P_CODE)
    private String inspOrderState;

    /**验收单状态翻译*/
    private String inspOrderStateStr;

    /**销售金额*/
    private BigDecimal totalSaleFee;

    /**采购金额*/
    private BigDecimal totalPurchaseFee;

    /**实付金额*/
    private BigDecimal usedFee;

    /**开票标识 0未开票 1已开票*/
    private Integer invoiceTag;

    /**流转状态*/
    private String procState;

    /**对账状态*/
    private String checkState;

    /**租户ID*/
    private String tenantId;

    /**竣工标志             1 竣工             0 在途*/
    private Integer finishFlag;

    /**创建时间*/
    private Date createTime;

    /**创建工号*/
    private String createOperId;

    /**验收人电话*/
    private String inspOperPhone;

    /**验收人名字*/
    private String inspOper;

    /**更新时间*/
    private Date updateTime;

    /**更新工号*/
    private String updateOperId;

    /**撤单时间*/
    private Date cancelTime;

    /**撤单工号*/
    private String cancelOperId;

    /**撤单原因*/
    private String cancelReason;

    /**撤单标志:1 已撤单             0 未撤单*/
    private Integer cancelFlag;

    /**备注*/
    private String remark;

    /**其它备注*/
    private String otherRemark;

    /**竣工时间*/
    private Date finishTime;

    /**逾期时间*/
    private Date expTime;

    /**总金额*/
    private BigDecimal totalFee;

    /**总数量*/
    private Integer totalCount;

    /**验收明细*/
    private List<UocGetSaleOrderDetailServiceRspInspOrderItemInfoBo> inspOrderItemInfo;

    /**验收发货关系*/
    private List<UocGetSaleOrderDetailServiceRspShipInspRelBo> shipInspRel;

    /**纵向扩展*/
    private List<UocGetSaleOrderDetailServiceRspInspOrderExtParallelBo> extParallelBoList;

}
